@@ -1,9 +1,9 @@
 import argparse
 from time import time
 
-from .source import *
+from source import *
 
-__version__ = '0.2.1'
+__version__ = '0.3.0'
 __author__ = 'Matthew Lam'
 __email__ = 'lcpmatthew@gmail.com'
 """
